@@ -1,29 +1,30 @@
-use v5.12.0;
-package App::Uni v0.14.0;
-use open ':std' => ':utf8';
-use File::ShareDir 'dist_dir';
+#!/usr/bin/perl
+package App::Uni;
+use 5.008;
+use strict;
+use warnings;
+use constant SOURCE => 'unicore/UnicodeData.txt';
+our $VERSION = '0.01';
 
 sub main {
-    my $dir = dist_dir('App-Uni');
-    my $file = "$dir/UnicodeData.txt";
-    (-f $file and -r $file)
-        or die "Cannot find UnicodeData.txt in $dir";
+    my ($file) = grep -f, map { "$_/".SOURCE } @INC
+        or die "Cannot find: ".SOURCE;
 
-    utf8::decode(
-        my $regex = join(' ', @_)
-    );
+    binmode STDOUT, ':utf8';
+    open my $fh, '<', $file
+        or die "Cannot open $file: $!";
 
-    if (length $regex == 1) {
-        $regex = sprintf('(?:%s|%04X)', $regex, ord $regex);
+    my $regex = join ' ', @_;
+
+    while (<$fh>) {
+        /$regex/io and /(\w+);([^;]+)/ or next;
+
+        my ($code, $name) = ($1, $2);
+        $name =~ /$regex/io or $code =~ /$regex/io or next;
+
+        print $code, ' ', chr hex $code, ' ', $name, $/;
     }
 
-    open my $fh, '<:mmap', $file;
-    for (<$fh>) {
-        if (/$regex/io and my ($code, $name) = /(\w+);([^;]+)/) {
-            say $code, ' ', chr hex $code, ' ', $name
-                if [$name, $code] ~~ /$regex/io;
-        }
-    }
     close $fh;
 }
 
@@ -39,29 +40,23 @@ App::Uni - Command-line utility to grep UnicodeData.txt
 
 =head1 VERSION
 
-This document describes version v0.14.0 of App::Uni, released June 7, 2011.
+This document describes version 0.01 of App::Uni, released December 10, 2009.
 
 =head1 SYNOPSIS
 
-    $ uni smiling face
+    $ uni smiling
     263A ☺ WHITE SMILING FACE
     263B ☻ BLACK SMILING FACE
 
-    $ uni ☺
-    263A ☺ WHITE SMILING FACE
-
 =head1 DESCRIPTION
 
 This module installs a simple program, F<uni>, that helps grepping through
-the Unicode database (bundled with this distribution).
+the Unicode database included in the current Perl 5 installation.
 
 The arguments to the F<uni> program are joined with space and interpreted
 as a regular expression.  Character codes or names matching the regex
 (case-insensitively) are then printed out.
 
-If the argument is a single character, then the character itself is also
-printed out in addition to code and name matches.
-
 =head1 ACKNOWLEDGEMENTS
 
 This is a re-implementation of a same-named program Larry copied to me,
@@ -77,7 +72,7 @@ Thank-you, Larry, for everything. ♡
 =head1 CC0 1.0 Universal
 
 To the extent possible under law, 唐鳳 has waived all copyright and related
-or neighboring rights to App-Uni.
+or neighboring rights to Module-Signature.
 
 This work is published from Taiwan.
 
